@@ -80,6 +80,11 @@ class SusType(SusTypeBase):
                     return "Bin[len] must be a range"
         elif self.name not in identifiers:
             return "Unknown type"
+        else:
+            if len(self.args):
+                return f"{self.name} takes no arguments"
+            if len(self.validators):
+                return f"{self.name} can't be validated"
 
 @dataclass
 class SusCompoundMember(SusThing):
@@ -277,6 +282,7 @@ def convert_method(ast, file):
         elif directive.data in ["errors", "confirmations"]:
             lst = {"errors": errors, "confirmations": confirmations}[directive.data]
             for e in directive.children:
+                if not e: continue
                 if e.value in lst:
                     SourceError([Location(file, e.line, e.column, len(e.value))],
                         f"Duplicate member \"{e.value}\" for this directive").print_warn()
